@@ -25,6 +25,7 @@
 package org.xerial.snappy;
 
 import java.io.ByteArrayOutputStream;
+import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.HashMap;
@@ -44,6 +45,7 @@ public class OSInfo {
     public static final String IA64 = "ia64";
     public static final String PPC = "ppc";
     public static final String PPC64 = "ppc64";
+    public static final String PPC64LE = "ppc64le";
     public static final String IBMZ = "s390";
     public static final String IBMZ_64 = "s390x";
     public static final String AARCH_64 = "aarch64";
@@ -80,6 +82,9 @@ public class OSInfo {
         archMapping.put("power_pc", PPC);
         archMapping.put("power_rs", PPC);
 
+        //PowerPC 64bit Little Endian mappings
+        archMapping.put(PPC64LE, PPC64LE);
+
         // TODO: PowerPC 64bit mappings
         archMapping.put(PPC64, PPC64);
         archMapping.put("power64", PPC64);
@@ -172,7 +177,7 @@ public class OSInfo {
             }
 
             // Java 1.8 introduces a system property to determine armel or armhf
-            // http://bugs.java.com/bugdatabase/view_bug.do?bug_id=8005545
+            // https://bugs.openjdk.org/browse/JDK-8005545
             String abi = System.getProperty("sun.arch.abi");
             if(abi != null && abi.startsWith("gnueabihf")) {
                 return "armv7";
@@ -215,6 +220,10 @@ public class OSInfo {
             return "android-arm";
         }
 
+        if (isX64Musl()) {
+            return "x86_64-musl";
+        }
+
         if(osArch.startsWith("arm")) {
             osArch = resolveArmArchType();
         }
@@ -226,6 +235,14 @@ public class OSInfo {
         return translateArchNameToFolderName(osArch);
     }
 
+    private static boolean isX64Musl() {
+        try {
+            return new File("/lib/ld-musl-x86_64.so.1").exists();
+        } catch (SecurityException e) {
+            return false;
+        }
+    }
+
     static String translateOSNameToFolderName(String osName) {
         if(osName.contains("Windows")) {
             return "Windows";
